@@ -150,9 +150,9 @@ double logLikelihood(arma::mat& posterior, arma::mat& logDensity,
 //'  data could be every characteristic influencing the reliability of a product,
 //'  e.g. operating time (days/months in service), mileage (km, miles), load
 //'  cycles.
-//' @param event a vector of binary data (0 or 1) indicating whether unit \emph{i}
+//' @param status a vector of binary data (0 or 1) indicating whether unit \emph{i}
 //'   is a right censored observation (= 0) or a failure (= 1).
-//' @param post a numeric matrix specifiying initial a-posteriori probabilities.
+//' @param post a numeric matrix specifying initial a-posteriori probabilities.
 //'   The number of rows have to be in line with observations \code{x} and the
 //'   number of columns must equal the mixture components \code{k}.
 //' @param distribution supposed distribution of mixture model components.
@@ -173,33 +173,18 @@ double logLikelihood(arma::mat& posterior, arma::mat& logDensity,
 //'   \item \code{posteriori} : A matrix with estimated a-posteriori probabilities.
 //'   \item \code{priori} : A vector with estimated a-priori probabilities.
 //'   \item \code{logL} : The value of the complete log-likelihood.}
-//' @export
-//' @examples
-//' # Data is taken from given reference:
-//' hours <- c(2, 28, 67, 119, 179, 236, 282, 317, 348, 387, 3, 31, 69, 135,
-//'           191, 241, 284, 318, 348, 392, 5, 31, 76, 144, 203, 257, 286,
-//'           320, 350, 412, 8, 52, 78, 157, 211, 261, 298, 327, 360, 446,
-//'           13, 53, 104, 160, 221, 264, 303, 328, 369, 21, 64, 113, 168,
-//'           226, 278, 314, 328, 377)
-//' state <- c(1, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 0, 1,
-//'          1, 0, 1, 1, 0, 1, 1, 1, 0, 1, 1, 1, 1, 1, 0, 0, 0,
-//'          1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1,
-//'          0, 1, 1, 1, 1, 1, 1)
-//' post_dirichlet <- LearnBayes::rdirichlet(n = length(hours),
-//'                                          par = rep(.1, 2))
-//' mix_mod_em <- mixture_em_cpp(x = hours,
-//'                              event = state,
-//'                              post = post_dirichlet,
-//'                              distribution = "weibull",
-//'                              k = 2,
-//'                              method = "EM",
-//'                              n_iter = 150)
 //'
+//' @keywords internal
 // [[Rcpp::export]]
-List mixture_em_cpp(NumericVector& x, NumericVector& event, NumericMatrix post,
-                    String distribution = "weibull", int k = 2,
-                    String method = "EM", int n_iter = 100,
-                    double conv_limit = 1e-6) {
+List mixture_em_cpp(NumericVector& x,
+                    NumericVector& status,
+                    NumericMatrix post,
+                    String distribution = "weibull",
+                    int k = 2,
+                    String method = "EM",
+                    int n_iter = 100,
+                    double conv_limit = 1e-6
+) {
 
   int n = x.length();
 
@@ -217,13 +202,13 @@ List mixture_em_cpp(NumericVector& x, NumericVector& event, NumericMatrix post,
 
     //######## M-Step ###########
     if (method == "EM") {
-      parameter = MStepWeibull(x, posterior, event);
+      parameter = MStepWeibull(x, posterior, status);
     }
 
     //######## E-Step ###########
     arma::mat posterior_old = as<arma::mat>(posterior);
 
-    LikelihoodWeibull(x, parameter, event, prior, posterior, logL);
+    LikelihoodWeibull(x, parameter, status, prior, posterior, logL);
 
     normalize(posterior);
     prior = colMeans(posterior);
@@ -233,7 +218,7 @@ List mixture_em_cpp(NumericVector& x, NumericVector& event, NumericMatrix post,
     NumericVector logPrior = log(prior);
     arma::vec logPrio = as<arma::vec>(logPrior);
 
-    double logLikelihood_new =logLikelihood(posterior_old, logDensity, logPrio);
+    double logLikelihood_new = logLikelihood(posterior_old, logDensity, logPrio);
 
     double convCrit = (std::abs(logLikelihood_new - logLikelihood_old) /
                       (std::abs(logLikelihood_old) + 0.001 * conv_limit));
